@@ -3,7 +3,7 @@
 
 ProximitySensor* ProximitySensor::me=NULL;
 
-ProximitySensor::ProximitySensor()
+ProximitySensor::ProximitySensor(Launcher* launcher_):launcher(launcher_)
 {
 
 	tapDuration=60;
@@ -17,7 +17,6 @@ ProximitySensor::ProximitySensor()
 	longPress="phone";
 	hold="proximityToggle";
 
-	paramPhone="rtcom-call-ui";
 	paramVib="PatternTocuhScreen";
 
 	tap=0;
@@ -41,19 +40,10 @@ void ProximitySensor::start()
 
 	connectToDbusVibra();
 	connectToDbusLock();
-	connectToDbusPhone();
 	connectToDbusProx();
-	dpy = XOpenDisplay("");
 
-	if (!dpy) 
-	{
-		exit(1);
-	}
 
 	ppid = getpid();
-	scr = DefaultScreen(dpy);
-	win = RootWindow(dpy, scr);
-	XGetGeometry(dpy, win, &ret_win, &x, &y, &width, &height, &border_width, &depth);
 	sleep(5);
 	startSensor();
 
@@ -376,129 +366,29 @@ void ProximitySensor::stopSensor()
 
 
 
-
-
-void ProximitySensor::connectToDbusPhone()
-{
-	dbus_error_init(&errPhone);
-	connPhone=dbus_bus_get_private(DBUS_BUS_SESSION, &errPhone);
-
-	if (dbus_error_is_set(&errPhone)) 
-	{ 
-		DebugPrint("PHONE: Connection Error");
-		dbus_error_free(&errPhone); 
-	}
-
-	if (NULL == connPhone) 
-	{ 
-		return; 
-	}
-
-	connectedPhone=1;
-
-}
-
-
-void ProximitySensor::launchPhone()
-{
-
-	if (connPhone==NULL)
-	{
-		connectToDbusPhone();
-			if (connPhone==NULL)
-				return;
-	}	
-
-
-	msgPhone = dbus_message_new_method_call("com.nokia.HildonDesktop.AppMgr", 
-						"/com/nokia/HildonDesktop/AppMgr",
-						"com.nokia.HildonDesktop.AppMgr", 
-						"LaunchApplication"); 
-   
-	if (NULL == msgPhone)
-	{	
-		DebugPrint("PHONE: Message Null");
-		return;
-	}
-
-	dbus_message_iter_init_append(msgPhone, &argsPhone);
-	if (!dbus_message_iter_append_basic(&argsPhone, DBUS_TYPE_STRING, &paramPhone)) 
-	{
-		DebugPrint("PHONE: Out Of Memory");
-		return;
-	}
-
-	if (!dbus_connection_send_with_reply (connPhone, msgPhone, &pendingPhone, -1)) 
-	{
-		DebugPrint("PHONE: Out of Memory");
-		return;
-	}
-	
-	if (NULL == pendingPhone) 
-	{
-		DebugPrint("PHONE: Pending Call Null");
-		return;
-	}
-	
-	dbus_connection_flush(connPhone);
-	dbus_message_unref(msgPhone);
-	dbus_pending_call_block(pendingPhone);
-	msgPhone = dbus_pending_call_steal_reply(pendingPhone);
-  
-	if (NULL == msgPhone) 
-	{
-		DebugPrint("PHONE: Reply Null");
-		return;
-	}
-   dbus_pending_call_unref(pendingPhone);
-   DebugPrint("PHONE: launched");
-}
-
-void ProximitySensor::dash()
-{
-	//vibrate(0);
-	
-	keycode = 37;
-	is_down=1;
-
-	XTestFakeKeyEvent(dpy, keycode, is_down, 0);
-	XSync(dpy, 1);
-
-	keycode = 22;
-	is_down=1;
-
-	XTestFakeKeyEvent(dpy, keycode, is_down, 0);
-	XSync(dpy, 1);
-
-	keycode = 22;
-	is_down=0;
-
-	XTestFakeKeyEvent(dpy, keycode, is_down, 0);
-	XSync(dpy, 1);
-
-	keycode = 37;
-	is_down=0;
-
-	XTestFakeKeyEvent(dpy, keycode, is_down, 0);
-	XSync(dpy, 1);
-
-	DebugPrint("DASH: launched");
-}
-
-
 void ProximitySensor::doShortPress()
 {
 	if (shortPress.compare("dashboard")==0)
-		dash();
-
+		launcher->Dashboard();
+	if (shortPress.compare("phone")==0)
+		launcher->Phone();
+	if (shortPress.compare("menu")==0)
+		launcher->Menu();
+    if (shortPress.compare("backspace")==0)
+        launcher->Backspace();
 
 }
 
 void ProximitySensor::doLongPress()
 {
 	if (longPress.compare("phone")==0)
-		launchPhone();
-
+		launcher->Phone();
+	if (longPress.compare("dashboard")==0)
+		launcher->Dashboard();
+	if (longPress.compare("menu")==0)
+		launcher->Menu();
+    if (longPress.compare("backspace")==0)
+        launcher->Backspace();
 }
 
 
