@@ -1,27 +1,30 @@
 #ifndef _PROXIMITY_H_
 #define _PROXIMITY_H_
 
-#include <iostream>
-#include <stdlib.h>
+//#include <iostream>
+//#include <stdlib.h>
 
-#include <ctype.h>
-#include <X11/Xlib.h>
-#include <X11/extensions/XTest.h>
-#include <unistd.h>
+//#include <ctype.h>
+//#include <X11/Xlib.h>
+//#include <X11/extensions/XTest.h>
+//#include <unistd.h>
 
-#include <dbus/dbus.h>
-#include <dbus/dbus-glib.h>
-#include <pthread.h>
+//#include <dbus/dbus.h>
+//#include <dbus/dbus-glib.h>
+//#include <pthread.h>
 
-#include <unistd.h>
-#include "shortcutd.h"
-#include <sys/types.h>
-#include <sys/stat.h>
+//#include "shortcutd.h"
+//#include <sys/types.h>
+//#include <sys/stat.h>
+
+#include "launcher.h"
 
 #define INTERVAL_IDLE 1000000
 #define INTERVAL_ACTIVE 1000
 
 
+class Launcher;
+
 class ProximitySensor
 {
 	private:
@@ -43,28 +46,6 @@ class ProximitySensor
 		int keyboardLocked;
 
 		
-		Display *dpy;
-		int scr;
-		Window win;
-		unsigned int width, height;
-		int keycode , is_down;
-		
-		FILE *fp;
-		
-		Window ret_win;
-		int x, y;
-		unsigned int border_width, depth;
-
-		int connectedPhone;
-		DBusMessage* msgPhone;
-		DBusMessageIter argsPhone;
-		DBusConnection* connPhone;
-		DBusError errPhone;
-		int retPhone;
-		DBusPendingCall* pendingPhone;
-		int stat;
-		dbus_uint32_t level;
-		const char* paramPhone;
 
 		int connectedLock;
 		DBusMessage* msgLock;
@@ -96,8 +77,6 @@ class ProximitySensor
 		
 		void connectToDbusLock();
 		
-		void connectToDbusPhone();
-		void launchPhone();
 	
 
 		void connectToDbusProx();
@@ -106,12 +85,12 @@ class ProximitySensor
 		DBusMessageIter argsProxSen;
 		DBusPendingCall* pendingProxSen;
 
+		Launcher* launcher;
 		
 		int ppid;
 		void startSensor();
 		void stopSensor();
 		
-		void dash();
 		char readProx();
 		int inCheck;
 
@@ -127,7 +106,7 @@ class ProximitySensor
 
 
 	public:
-		ProximitySensor();
+		ProximitySensor(Launcher* launcher_);
 		~ProximitySensor();
 		int interval;
 		void start();
